<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyIsuRequest;
use App\Http\Requests\StoreIsuRequest;
use App\Http\Requests\UpdateIsuRequest;
use App\Models\Isu;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class IsuController extends Controller
{
    use MediaUploadingTrait, CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('isu_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = Isu::query()->select(sprintf('%s.*', (new Isu)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'isu_show';
                $editGate      = 'isu_edit';
                $deleteGate    = 'isu_delete';
                $crudRoutePart = 'isus';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('perkara', function ($row) {
                return $row->perkara ? $row->perkara : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.isus.index');
    }

    public function create()
    {
        abort_if(Gate::denies('isu_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.isus.create');
    }

    public function store(StoreIsuRequest $request)
    {
        $isu = Isu::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $isu->id]);
        }

        return redirect()->route('admin.isus.index');
    }

    public function edit(Isu $isu)
    {
        abort_if(Gate::denies('isu_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.isus.edit', compact('isu'));
    }

    public function update(UpdateIsuRequest $request, Isu $isu)
    {
        $isu->update($request->all());

        return redirect()->route('admin.isus.index');
    }

    public function show(Isu $isu)
    {
        abort_if(Gate::denies('isu_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.isus.show', compact('isu'));
    }

    public function destroy(Isu $isu)
    {
        abort_if(Gate::denies('isu_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $isu->delete();

        return back();
    }

    public function massDestroy(MassDestroyIsuRequest $request)
    {
        $isus = Isu::find(request('ids'));

        foreach ($isus as $isu) {
            $isu->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('isu_create') && Gate::denies('isu_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new Isu();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
