<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyKategoriBilanganRequest;
use App\Http\Requests\StoreKategoriBilanganRequest;
use App\Http\Requests\UpdateKategoriBilanganRequest;
use App\Models\KategoriBilangan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class KategoriBilanganController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('kategori_bilangan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = KategoriBilangan::query()->select(sprintf('%s.*', (new KategoriBilangan)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'kategori_bilangan_show';
                $editGate      = 'kategori_bilangan_edit';
                $deleteGate    = 'kategori_bilangan_delete';
                $crudRoutePart = 'kategori-bilangans';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('bilangan', function ($row) {
                return $row->bilangan ? $row->bilangan : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.kategoriBilangans.index');
    }

    public function create()
    {
        abort_if(Gate::denies('kategori_bilangan_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.kategoriBilangans.create');
    }

    public function store(StoreKategoriBilanganRequest $request)
    {
        $kategoriBilangan = KategoriBilangan::create($request->all());

        return redirect()->route('admin.kategori-bilangans.index');
    }

    public function edit(KategoriBilangan $kategoriBilangan)
    {
        abort_if(Gate::denies('kategori_bilangan_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.kategoriBilangans.edit', compact('kategoriBilangan'));
    }

    public function update(UpdateKategoriBilanganRequest $request, KategoriBilangan $kategoriBilangan)
    {
        $kategoriBilangan->update($request->all());

        return redirect()->route('admin.kategori-bilangans.index');
    }

    public function show(KategoriBilangan $kategoriBilangan)
    {
        abort_if(Gate::denies('kategori_bilangan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriBilangan->load('bilRekodPulangans');

        return view('admin.kategoriBilangans.show', compact('kategoriBilangan'));
    }

    public function destroy(KategoriBilangan $kategoriBilangan)
    {
        abort_if(Gate::denies('kategori_bilangan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriBilangan->delete();

        return back();
    }

    public function massDestroy(MassDestroyKategoriBilanganRequest $request)
    {
        $kategoriBilangans = KategoriBilangan::find(request('ids'));

        foreach ($kategoriBilangans as $kategoriBilangan) {
            $kategoriBilangan->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
