<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyKategoriPihakRequest;
use App\Http\Requests\StoreKategoriPihakRequest;
use App\Http\Requests\UpdateKategoriPihakRequest;
use App\Models\KategoriPihak;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class KategoriPihakController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('kategori_pihak_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = KategoriPihak::query()->select(sprintf('%s.*', (new KategoriPihak)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'kategori_pihak_show';
                $editGate      = 'kategori_pihak_edit';
                $deleteGate    = 'kategori_pihak_delete';
                $crudRoutePart = 'kategori-pihaks';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('nama_pihak', function ($row) {
                return $row->nama_pihak ? $row->nama_pihak : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.kategoriPihaks.index');
    }

    public function create()
    {
        abort_if(Gate::denies('kategori_pihak_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.kategoriPihaks.create');
    }

    public function store(StoreKategoriPihakRequest $request)
    {
        $kategoriPihak = KategoriPihak::create($request->all());

        return redirect()->route('admin.kategori-pihaks.index');
    }

    public function edit(KategoriPihak $kategoriPihak)
    {
        abort_if(Gate::denies('kategori_pihak_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.kategoriPihaks.edit', compact('kategoriPihak'));
    }

    public function update(UpdateKategoriPihakRequest $request, KategoriPihak $kategoriPihak)
    {
        $kategoriPihak->update($request->all());

        return redirect()->route('admin.kategori-pihaks.index');
    }

    public function show(KategoriPihak $kategoriPihak)
    {
        abort_if(Gate::denies('kategori_pihak_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriPihak->load('pihakRekodPulangans');

        return view('admin.kategoriPihaks.show', compact('kategoriPihak'));
    }

    public function destroy(KategoriPihak $kategoriPihak)
    {
        abort_if(Gate::denies('kategori_pihak_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriPihak->delete();

        return back();
    }

    public function massDestroy(MassDestroyKategoriPihakRequest $request)
    {
        $kategoriPihaks = KategoriPihak::find(request('ids'));

        foreach ($kategoriPihaks as $kategoriPihak) {
            $kategoriPihak->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
