<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyKomponenPembangunanRequest;
use App\Http\Requests\StoreKomponenPembangunanRequest;
use App\Http\Requests\UpdateKomponenPembangunanRequest;
use App\Models\KomponenPembangunan;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class KomponenPembangunanController extends Controller
{
    use MediaUploadingTrait, CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('komponen_pembangunan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = KomponenPembangunan::query()->select(sprintf('%s.*', (new KomponenPembangunan)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'komponen_pembangunan_show';
                $editGate      = 'komponen_pembangunan_edit';
                $deleteGate    = 'komponen_pembangunan_delete';
                $crudRoutePart = 'komponen-pembangunans';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('gambaran_komponen', function ($row) {
                if (! $row->gambaran_komponen) {
                    return '';
                }
                $links = [];
                foreach ($row->gambaran_komponen as $media) {
                    $links[] = '<a href="' . $media->getUrl() . '" target="_blank">' . trans('global.downloadFile') . '</a>';
                }

                return implode(', ', $links);
            });
            $table->editColumn('gambar_semasa_projek', function ($row) {
                if (! $row->gambar_semasa_projek) {
                    return '';
                }
                $links = [];
                foreach ($row->gambar_semasa_projek as $media) {
                    $links[] = '<a href="' . $media->getUrl() . '" target="_blank"><img src="' . $media->getUrl('thumb') . '" width="50px" height="50px"></a>';
                }

                return implode(' ', $links);
            });
            $table->editColumn('fasa', function ($row) {
                return $row->fasa ? KomponenPembangunan::FASA_SELECT[$row->fasa] : '';
            });
            $table->editColumn('komponen', function ($row) {
                return $row->komponen ? $row->komponen : '';
            });
            $table->editColumn('keluasan_lot', function ($row) {
                return $row->keluasan_lot ? $row->keluasan_lot : '';
            });
            $table->editColumn('keluasan_bangunan', function ($row) {
                return $row->keluasan_bangunan ? $row->keluasan_bangunan : '';
            });
            $table->editColumn('harga', function ($row) {
                return $row->harga ? $row->harga : '';
            });
            $table->editColumn('jumlah_unit', function ($row) {
                return $row->jumlah_unit ? $row->jumlah_unit : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'gambaran_komponen', 'gambar_semasa_projek']);

            return $table->make(true);
        }

        return view('admin.komponenPembangunans.index');
    }

    public function create()
    {
        abort_if(Gate::denies('komponen_pembangunan_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.komponenPembangunans.create');
    }

    public function store(StoreKomponenPembangunanRequest $request)
    {
        $komponenPembangunan = KomponenPembangunan::create($request->all());

        foreach ($request->input('gambaran_komponen', []) as $file) {
            $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambaran_komponen');
        }

        foreach ($request->input('gambar_semasa_projek', []) as $file) {
            $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambar_semasa_projek');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $komponenPembangunan->id]);
        }

        return redirect()->route('admin.komponen-pembangunans.index');
    }

    public function edit(KomponenPembangunan $komponenPembangunan)
    {
        abort_if(Gate::denies('komponen_pembangunan_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.komponenPembangunans.edit', compact('komponenPembangunan'));
    }

    public function update(UpdateKomponenPembangunanRequest $request, KomponenPembangunan $komponenPembangunan)
    {
        $komponenPembangunan->update($request->all());

        if (count($komponenPembangunan->gambaran_komponen) > 0) {
            foreach ($komponenPembangunan->gambaran_komponen as $media) {
                if (! in_array($media->file_name, $request->input('gambaran_komponen', []))) {
                    $media->delete();
                }
            }
        }
        $media = $komponenPembangunan->gambaran_komponen->pluck('file_name')->toArray();
        foreach ($request->input('gambaran_komponen', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambaran_komponen');
            }
        }

        if (count($komponenPembangunan->gambar_semasa_projek) > 0) {
            foreach ($komponenPembangunan->gambar_semasa_projek as $media) {
                if (! in_array($media->file_name, $request->input('gambar_semasa_projek', []))) {
                    $media->delete();
                }
            }
        }
        $media = $komponenPembangunan->gambar_semasa_projek->pluck('file_name')->toArray();
        foreach ($request->input('gambar_semasa_projek', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambar_semasa_projek');
            }
        }

        return redirect()->route('admin.komponen-pembangunans.index');
    }

    public function show(KomponenPembangunan $komponenPembangunan)
    {
        abort_if(Gate::denies('komponen_pembangunan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.komponenPembangunans.show', compact('komponenPembangunan'));
    }

    public function destroy(KomponenPembangunan $komponenPembangunan)
    {
        abort_if(Gate::denies('komponen_pembangunan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $komponenPembangunan->delete();

        return back();
    }

    public function massDestroy(MassDestroyKomponenPembangunanRequest $request)
    {
        $komponenPembangunans = KomponenPembangunan::find(request('ids'));

        foreach ($komponenPembangunans as $komponenPembangunan) {
            $komponenPembangunan->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('komponen_pembangunan_create') && Gate::denies('komponen_pembangunan_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new KomponenPembangunan();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
