<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyMaklumatPerundingRequest;
use App\Http\Requests\StoreMaklumatPerundingRequest;
use App\Http\Requests\UpdateMaklumatPerundingRequest;
use App\Models\MaklumatPerunding;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class MaklumatPerundingController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('maklumat_perunding_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = MaklumatPerunding::query()->select(sprintf('%s.*', (new MaklumatPerunding)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'maklumat_perunding_show';
                $editGate      = 'maklumat_perunding_edit';
                $deleteGate    = 'maklumat_perunding_delete';
                $crudRoutePart = 'maklumat-perundings';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('nama_syarikat_perunding_arkitek', function ($row) {
                return $row->nama_syarikat_perunding_arkitek ? $row->nama_syarikat_perunding_arkitek : '';
            });
            $table->editColumn('nama_syarikat_perunding_sivil_struktur', function ($row) {
                return $row->nama_syarikat_perunding_sivil_struktur ? $row->nama_syarikat_perunding_sivil_struktur : '';
            });
            $table->editColumn('nama_syarikat_perunding_mekanikal_elektrikal', function ($row) {
                return $row->nama_syarikat_perunding_mekanikal_elektrikal ? $row->nama_syarikat_perunding_mekanikal_elektrikal : '';
            });
            $table->editColumn('nama_syarikat_perunding_juru_ukur_tanah', function ($row) {
                return $row->nama_syarikat_perunding_juru_ukur_tanah ? $row->nama_syarikat_perunding_juru_ukur_tanah : '';
            });
            $table->editColumn('nama_syarikat_perunding_juru_ukur_bahan', function ($row) {
                return $row->nama_syarikat_perunding_juru_ukur_bahan ? $row->nama_syarikat_perunding_juru_ukur_bahan : '';
            });
            $table->editColumn('nama_syarikat_perunding_arkitek_landskap', function ($row) {
                return $row->nama_syarikat_perunding_arkitek_landskap ? $row->nama_syarikat_perunding_arkitek_landskap : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.maklumatPerundings.index');
    }

    public function create()
    {
        abort_if(Gate::denies('maklumat_perunding_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatPerundings.create');
    }

    public function store(StoreMaklumatPerundingRequest $request)
    {
        $maklumatPerunding = MaklumatPerunding::create($request->all());

        return redirect()->route('admin.maklumat-perundings.index');
    }

    public function edit(MaklumatPerunding $maklumatPerunding)
    {
        abort_if(Gate::denies('maklumat_perunding_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatPerundings.edit', compact('maklumatPerunding'));
    }

    public function update(UpdateMaklumatPerundingRequest $request, MaklumatPerunding $maklumatPerunding)
    {
        $maklumatPerunding->update($request->all());

        return redirect()->route('admin.maklumat-perundings.index');
    }

    public function show(MaklumatPerunding $maklumatPerunding)
    {
        abort_if(Gate::denies('maklumat_perunding_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatPerundings.show', compact('maklumatPerunding'));
    }

    public function destroy(MaklumatPerunding $maklumatPerunding)
    {
        abort_if(Gate::denies('maklumat_perunding_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $maklumatPerunding->delete();

        return back();
    }

    public function massDestroy(MassDestroyMaklumatPerundingRequest $request)
    {
        $maklumatPerundings = MaklumatPerunding::find(request('ids'));

        foreach ($maklumatPerundings as $maklumatPerunding) {
            $maklumatPerunding->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
