<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyMaklumatRakanUsahasamaRequest;
use App\Http\Requests\StoreMaklumatRakanUsahasamaRequest;
use App\Http\Requests\UpdateMaklumatRakanUsahasamaRequest;
use App\Models\MaklumatRakanUsahasama;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class MaklumatRakanUsahasamaController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('maklumat_rakan_usahasama_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = MaklumatRakanUsahasama::query()->select(sprintf('%s.*', (new MaklumatRakanUsahasama)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'maklumat_rakan_usahasama_show';
                $editGate      = 'maklumat_rakan_usahasama_edit';
                $deleteGate    = 'maklumat_rakan_usahasama_delete';
                $crudRoutePart = 'maklumat-rakan-usahasamas';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('nama_syarikat', function ($row) {
                return $row->nama_syarikat ? $row->nama_syarikat : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.maklumatRakanUsahasamas.index');
    }

    public function create()
    {
        abort_if(Gate::denies('maklumat_rakan_usahasama_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatRakanUsahasamas.create');
    }

    public function store(StoreMaklumatRakanUsahasamaRequest $request)
    {
        $maklumatRakanUsahasama = MaklumatRakanUsahasama::create($request->all());

        return redirect()->route('admin.maklumat-rakan-usahasamas.index');
    }

    public function edit(MaklumatRakanUsahasama $maklumatRakanUsahasama)
    {
        abort_if(Gate::denies('maklumat_rakan_usahasama_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatRakanUsahasamas.edit', compact('maklumatRakanUsahasama'));
    }

    public function update(UpdateMaklumatRakanUsahasamaRequest $request, MaklumatRakanUsahasama $maklumatRakanUsahasama)
    {
        $maklumatRakanUsahasama->update($request->all());

        return redirect()->route('admin.maklumat-rakan-usahasamas.index');
    }

    public function show(MaklumatRakanUsahasama $maklumatRakanUsahasama)
    {
        abort_if(Gate::denies('maklumat_rakan_usahasama_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.maklumatRakanUsahasamas.show', compact('maklumatRakanUsahasama'));
    }

    public function destroy(MaklumatRakanUsahasama $maklumatRakanUsahasama)
    {
        abort_if(Gate::denies('maklumat_rakan_usahasama_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $maklumatRakanUsahasama->delete();

        return back();
    }

    public function massDestroy(MassDestroyMaklumatRakanUsahasamaRequest $request)
    {
        $maklumatRakanUsahasamas = MaklumatRakanUsahasama::find(request('ids'));

        foreach ($maklumatRakanUsahasamas as $maklumatRakanUsahasama) {
            $maklumatRakanUsahasama->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
