<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyRekodPulanganRequest;
use App\Http\Requests\StoreRekodPulanganRequest;
use App\Http\Requests\UpdateRekodPulanganRequest;
use App\Models\KategoriBilangan;
use App\Models\KategoriPihak;
use App\Models\RekodPulangan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class RekodPulanganController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('rekod_pulangan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = RekodPulangan::with(['bil', 'pihak'])->select(sprintf('%s.*', (new RekodPulangan)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'rekod_pulangan_show';
                $editGate      = 'rekod_pulangan_edit';
                $deleteGate    = 'rekod_pulangan_delete';
                $crudRoutePart = 'rekod-pulangans';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->addColumn('bil_bilangan', function ($row) {
                return $row->bil ? $row->bil->bilangan : '';
            });

            $table->editColumn('perkara', function ($row) {
                return $row->perkara ? $row->perkara : '';
            });
            $table->addColumn('pihak_nama_pihak', function ($row) {
                return $row->pihak ? $row->pihak->nama_pihak : '';
            });

            $table->editColumn('jumlah_anggaran', function ($row) {
                return $row->jumlah_anggaran ? $row->jumlah_anggaran : '';
            });
            $table->editColumn('status_bayaran', function ($row) {
                return $row->status_bayaran ? RekodPulangan::STATUS_BAYARAN_SELECT[$row->status_bayaran] : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'bil', 'pihak']);

            return $table->make(true);
        }

        $kategori_bilangans = KategoriBilangan::get();
        $kategori_pihaks    = KategoriPihak::get();

        return view('admin.rekodPulangans.index', compact('kategori_bilangans', 'kategori_pihaks'));
    }

    public function create()
    {
        abort_if(Gate::denies('rekod_pulangan_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $bils = KategoriBilangan::pluck('bilangan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $pihaks = KategoriPihak::pluck('nama_pihak', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.rekodPulangans.create', compact('bils', 'pihaks'));
    }

    public function store(StoreRekodPulanganRequest $request)
    {
        $rekodPulangan = RekodPulangan::create($request->all());

        return redirect()->route('admin.rekod-pulangans.index');
    }

    public function edit(RekodPulangan $rekodPulangan)
    {
        abort_if(Gate::denies('rekod_pulangan_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $bils = KategoriBilangan::pluck('bilangan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $pihaks = KategoriPihak::pluck('nama_pihak', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rekodPulangan->load('bil', 'pihak');

        return view('admin.rekodPulangans.edit', compact('bils', 'pihaks', 'rekodPulangan'));
    }

    public function update(UpdateRekodPulanganRequest $request, RekodPulangan $rekodPulangan)
    {
        $rekodPulangan->update($request->all());

        return redirect()->route('admin.rekod-pulangans.index');
    }

    public function show(RekodPulangan $rekodPulangan)
    {
        abort_if(Gate::denies('rekod_pulangan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rekodPulangan->load('bil', 'pihak');

        return view('admin.rekodPulangans.show', compact('rekodPulangan'));
    }

    public function destroy(RekodPulangan $rekodPulangan)
    {
        abort_if(Gate::denies('rekod_pulangan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rekodPulangan->delete();

        return back();
    }

    public function massDestroy(MassDestroyRekodPulanganRequest $request)
    {
        $rekodPulangans = RekodPulangan::find(request('ids'));

        foreach ($rekodPulangans as $rekodPulangan) {
            $rekodPulangan->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
