<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyTempohPerlaksanaanProjekRequest;
use App\Http\Requests\StoreTempohPerlaksanaanProjekRequest;
use App\Http\Requests\UpdateTempohPerlaksanaanProjekRequest;
use App\Models\TempohPerlaksanaanProjek;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class TempohPerlaksanaanProjekController extends Controller
{
    use CsvImportTrait;

    public function index(Request $request)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = TempohPerlaksanaanProjek::query()->select(sprintf('%s.*', (new TempohPerlaksanaanProjek)->table));
            $table = Datatables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate      = 'tempoh_perlaksanaan_projek_show';
                $editGate      = 'tempoh_perlaksanaan_projek_edit';
                $deleteGate    = 'tempoh_perlaksanaan_projek_delete';
                $crudRoutePart = 'tempoh-perlaksanaan-projeks';

                return view('partials.datatablesActions', compact(
                    'viewGate',
                    'editGate',
                    'deleteGate',
                    'crudRoutePart',
                    'row'
                ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('perkara_pembangunan', function ($row) {
                return $row->perkara_pembangunan ? $row->perkara_pembangunan : '';
            });

            $table->rawColumns(['actions', 'placeholder']);

            return $table->make(true);
        }

        return view('admin.tempohPerlaksanaanProjeks.index');
    }

    public function create()
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.tempohPerlaksanaanProjeks.create');
    }

    public function store(StoreTempohPerlaksanaanProjekRequest $request)
    {
        $tempohPerlaksanaanProjek = TempohPerlaksanaanProjek::create($request->all());

        return redirect()->route('admin.tempoh-perlaksanaan-projeks.index');
    }

    public function edit(TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.tempohPerlaksanaanProjeks.edit', compact('tempohPerlaksanaanProjek'));
    }

    public function update(UpdateTempohPerlaksanaanProjekRequest $request, TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        $tempohPerlaksanaanProjek->update($request->all());

        return redirect()->route('admin.tempoh-perlaksanaan-projeks.index');
    }

    public function show(TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.tempohPerlaksanaanProjeks.show', compact('tempohPerlaksanaanProjek'));
    }

    public function destroy(TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $tempohPerlaksanaanProjek->delete();

        return back();
    }

    public function massDestroy(MassDestroyTempohPerlaksanaanProjekRequest $request)
    {
        $tempohPerlaksanaanProjeks = TempohPerlaksanaanProjek::find(request('ids'));

        foreach ($tempohPerlaksanaanProjeks as $tempohPerlaksanaanProjek) {
            $tempohPerlaksanaanProjek->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
