<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreIsuRequest;
use App\Http\Requests\UpdateIsuRequest;
use App\Http\Resources\Admin\IsuResource;
use App\Models\Isu;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class IsuApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('isu_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new IsuResource(Isu::all());
    }

    public function store(StoreIsuRequest $request)
    {
        $isu = Isu::create($request->all());

        return (new IsuResource($isu))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Isu $isu)
    {
        abort_if(Gate::denies('isu_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new IsuResource($isu);
    }

    public function update(UpdateIsuRequest $request, Isu $isu)
    {
        $isu->update($request->all());

        return (new IsuResource($isu))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Isu $isu)
    {
        abort_if(Gate::denies('isu_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $isu->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
