<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreKategoriBilanganRequest;
use App\Http\Requests\UpdateKategoriBilanganRequest;
use App\Http\Resources\Admin\KategoriBilanganResource;
use App\Models\KategoriBilangan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class KategoriBilanganApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('kategori_bilangan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KategoriBilanganResource(KategoriBilangan::all());
    }

    public function store(StoreKategoriBilanganRequest $request)
    {
        $kategoriBilangan = KategoriBilangan::create($request->all());

        return (new KategoriBilanganResource($kategoriBilangan))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(KategoriBilangan $kategoriBilangan)
    {
        abort_if(Gate::denies('kategori_bilangan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KategoriBilanganResource($kategoriBilangan);
    }

    public function update(UpdateKategoriBilanganRequest $request, KategoriBilangan $kategoriBilangan)
    {
        $kategoriBilangan->update($request->all());

        return (new KategoriBilanganResource($kategoriBilangan))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(KategoriBilangan $kategoriBilangan)
    {
        abort_if(Gate::denies('kategori_bilangan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriBilangan->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
