<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreKategoriPihakRequest;
use App\Http\Requests\UpdateKategoriPihakRequest;
use App\Http\Resources\Admin\KategoriPihakResource;
use App\Models\KategoriPihak;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class KategoriPihakApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('kategori_pihak_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KategoriPihakResource(KategoriPihak::all());
    }

    public function store(StoreKategoriPihakRequest $request)
    {
        $kategoriPihak = KategoriPihak::create($request->all());

        return (new KategoriPihakResource($kategoriPihak))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(KategoriPihak $kategoriPihak)
    {
        abort_if(Gate::denies('kategori_pihak_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KategoriPihakResource($kategoriPihak);
    }

    public function update(UpdateKategoriPihakRequest $request, KategoriPihak $kategoriPihak)
    {
        $kategoriPihak->update($request->all());

        return (new KategoriPihakResource($kategoriPihak))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(KategoriPihak $kategoriPihak)
    {
        abort_if(Gate::denies('kategori_pihak_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $kategoriPihak->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
