<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreKomponenPembangunanRequest;
use App\Http\Requests\UpdateKomponenPembangunanRequest;
use App\Http\Resources\Admin\KomponenPembangunanResource;
use App\Models\KomponenPembangunan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class KomponenPembangunanApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('komponen_pembangunan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KomponenPembangunanResource(KomponenPembangunan::all());
    }

    public function store(StoreKomponenPembangunanRequest $request)
    {
        $komponenPembangunan = KomponenPembangunan::create($request->all());

        foreach ($request->input('gambaran_komponen', []) as $file) {
            $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambaran_komponen');
        }

        foreach ($request->input('gambar_semasa_projek', []) as $file) {
            $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambar_semasa_projek');
        }

        return (new KomponenPembangunanResource($komponenPembangunan))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(KomponenPembangunan $komponenPembangunan)
    {
        abort_if(Gate::denies('komponen_pembangunan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new KomponenPembangunanResource($komponenPembangunan);
    }

    public function update(UpdateKomponenPembangunanRequest $request, KomponenPembangunan $komponenPembangunan)
    {
        $komponenPembangunan->update($request->all());

        if (count($komponenPembangunan->gambaran_komponen) > 0) {
            foreach ($komponenPembangunan->gambaran_komponen as $media) {
                if (! in_array($media->file_name, $request->input('gambaran_komponen', []))) {
                    $media->delete();
                }
            }
        }
        $media = $komponenPembangunan->gambaran_komponen->pluck('file_name')->toArray();
        foreach ($request->input('gambaran_komponen', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambaran_komponen');
            }
        }

        if (count($komponenPembangunan->gambar_semasa_projek) > 0) {
            foreach ($komponenPembangunan->gambar_semasa_projek as $media) {
                if (! in_array($media->file_name, $request->input('gambar_semasa_projek', []))) {
                    $media->delete();
                }
            }
        }
        $media = $komponenPembangunan->gambar_semasa_projek->pluck('file_name')->toArray();
        foreach ($request->input('gambar_semasa_projek', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $komponenPembangunan->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('gambar_semasa_projek');
            }
        }

        return (new KomponenPembangunanResource($komponenPembangunan))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(KomponenPembangunan $komponenPembangunan)
    {
        abort_if(Gate::denies('komponen_pembangunan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $komponenPembangunan->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
