<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreMaklumatPerundingRequest;
use App\Http\Requests\UpdateMaklumatPerundingRequest;
use App\Http\Resources\Admin\MaklumatPerundingResource;
use App\Models\MaklumatPerunding;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class MaklumatPerundingApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('maklumat_perunding_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new MaklumatPerundingResource(MaklumatPerunding::all());
    }

    public function store(StoreMaklumatPerundingRequest $request)
    {
        $maklumatPerunding = MaklumatPerunding::create($request->all());

        return (new MaklumatPerundingResource($maklumatPerunding))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(MaklumatPerunding $maklumatPerunding)
    {
        abort_if(Gate::denies('maklumat_perunding_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new MaklumatPerundingResource($maklumatPerunding);
    }

    public function update(UpdateMaklumatPerundingRequest $request, MaklumatPerunding $maklumatPerunding)
    {
        $maklumatPerunding->update($request->all());

        return (new MaklumatPerundingResource($maklumatPerunding))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(MaklumatPerunding $maklumatPerunding)
    {
        abort_if(Gate::denies('maklumat_perunding_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $maklumatPerunding->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
