<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreMaklumatProjectRequest;
use App\Http\Requests\UpdateMaklumatProjectRequest;
use App\Http\Resources\Admin\MaklumatProjectResource;
use App\Models\MaklumatProject;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class MaklumatProjectApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('maklumat_project_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new MaklumatProjectResource(MaklumatProject::all());
    }

    public function store(StoreMaklumatProjectRequest $request)
    {
        $maklumatProject = MaklumatProject::create($request->all());

        foreach ($request->input('pelan_kunci', []) as $file) {
            $maklumatProject->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('pelan_kunci');
        }

        foreach ($request->input('pelan_lokasi', []) as $file) {
            $maklumatProject->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('pelan_lokasi');
        }

        return (new MaklumatProjectResource($maklumatProject))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(MaklumatProject $maklumatProject)
    {
        abort_if(Gate::denies('maklumat_project_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new MaklumatProjectResource($maklumatProject);
    }

    public function update(UpdateMaklumatProjectRequest $request, MaklumatProject $maklumatProject)
    {
        $maklumatProject->update($request->all());

        if (count($maklumatProject->pelan_kunci) > 0) {
            foreach ($maklumatProject->pelan_kunci as $media) {
                if (! in_array($media->file_name, $request->input('pelan_kunci', []))) {
                    $media->delete();
                }
            }
        }
        $media = $maklumatProject->pelan_kunci->pluck('file_name')->toArray();
        foreach ($request->input('pelan_kunci', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $maklumatProject->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('pelan_kunci');
            }
        }

        if (count($maklumatProject->pelan_lokasi) > 0) {
            foreach ($maklumatProject->pelan_lokasi as $media) {
                if (! in_array($media->file_name, $request->input('pelan_lokasi', []))) {
                    $media->delete();
                }
            }
        }
        $media = $maklumatProject->pelan_lokasi->pluck('file_name')->toArray();
        foreach ($request->input('pelan_lokasi', []) as $file) {
            if (count($media) === 0 || ! in_array($file, $media)) {
                $maklumatProject->addMedia(storage_path('tmp/uploads/' . basename($file)))->toMediaCollection('pelan_lokasi');
            }
        }

        return (new MaklumatProjectResource($maklumatProject))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(MaklumatProject $maklumatProject)
    {
        abort_if(Gate::denies('maklumat_project_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $maklumatProject->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
