<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreRekodPulanganRequest;
use App\Http\Requests\UpdateRekodPulanganRequest;
use App\Http\Resources\Admin\RekodPulanganResource;
use App\Models\RekodPulangan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RekodPulanganApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rekod_pulangan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new RekodPulanganResource(RekodPulangan::with(['bil', 'pihak'])->get());
    }

    public function store(StoreRekodPulanganRequest $request)
    {
        $rekodPulangan = RekodPulangan::create($request->all());

        return (new RekodPulanganResource($rekodPulangan))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(RekodPulangan $rekodPulangan)
    {
        abort_if(Gate::denies('rekod_pulangan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new RekodPulanganResource($rekodPulangan->load(['bil', 'pihak']));
    }

    public function update(UpdateRekodPulanganRequest $request, RekodPulangan $rekodPulangan)
    {
        $rekodPulangan->update($request->all());

        return (new RekodPulanganResource($rekodPulangan))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(RekodPulangan $rekodPulangan)
    {
        abort_if(Gate::denies('rekod_pulangan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rekodPulangan->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
