<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreTempohPerlaksanaanProjekRequest;
use App\Http\Requests\UpdateTempohPerlaksanaanProjekRequest;
use App\Http\Resources\Admin\TempohPerlaksanaanProjekResource;
use App\Models\TempohPerlaksanaanProjek;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class TempohPerlaksanaanProjekApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new TempohPerlaksanaanProjekResource(TempohPerlaksanaanProjek::all());
    }

    public function store(StoreTempohPerlaksanaanProjekRequest $request)
    {
        $tempohPerlaksanaanProjek = TempohPerlaksanaanProjek::create($request->all());

        return (new TempohPerlaksanaanProjekResource($tempohPerlaksanaanProjek))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new TempohPerlaksanaanProjekResource($tempohPerlaksanaanProjek);
    }

    public function update(UpdateTempohPerlaksanaanProjekRequest $request, TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        $tempohPerlaksanaanProjek->update($request->all());

        return (new TempohPerlaksanaanProjekResource($tempohPerlaksanaanProjek))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(TempohPerlaksanaanProjek $tempohPerlaksanaanProjek)
    {
        abort_if(Gate::denies('tempoh_perlaksanaan_projek_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $tempohPerlaksanaanProjek->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
