<?php

namespace App\Models;

use App\Traits\Auditable;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class KomponenPembangunan extends Model implements HasMedia
{
    use SoftDeletes, InteractsWithMedia, Auditable, HasFactory;

    public $table = 'komponen_pembangunans';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $appends = [
        'gambaran_komponen',
        'gambar_semasa_projek',
    ];

    protected $fillable = [
        'fasa',
        'komponen',
        'keluasan_lot',
        'keluasan_bangunan',
        'harga',
        'jumlah_unit',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const FASA_SELECT = [
        '1'  => '1',
        '2'  => '2',
        '2A' => '2A',
        '2B' => '2B',
        '3'  => '3',
        '3A' => '3A',
        '3B' => '3B',
        '4'  => '4',
        '4A' => '4A',
        '4B' => '4B',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function getGambaranKomponenAttribute()
    {
        return $this->getMedia('gambaran_komponen');
    }

    public function getGambarSemasaProjekAttribute()
    {
        $files = $this->getMedia('gambar_semasa_projek');
        $files->each(function ($item) {
            $item->url       = $item->getUrl();
            $item->thumbnail = $item->getUrl('thumb');
            $item->preview   = $item->getUrl('preview');
        });

        return $files;
    }
}
