<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class MaklumatProject extends Model implements HasMedia
{
    use SoftDeletes, InteractsWithMedia, Auditable, HasFactory;

    public $table = 'maklumat_projects';

    protected $appends = [
        'pelan_kunci',
        'pelan_lokasi',
    ];

    public static $searchable = [
        'pelan_kunci',
        'pelan_lokasi',
    ];

    protected $dates = [
        'tarikh_pa',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const KATEGORI_PENGGUNAAN_TANAH_SELECT = [
        'Bangunan'  => 'Bangunan',
        'Pertanian' => 'Pertanian',
        'Industri'  => 'Industri',
    ];

    protected $fillable = [
        'lot',
        'mukim',
        'daerah',
        'keluasan',
        'kategori_penggunaan_tanah',
        'sekatan_sekatan_penting',
        'tarikh_pa',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const DAERAH_SELECT = [
        'Timur Laut'             => 'Timur Laut (TL)',
        'Barat Daya'             => 'Barat Daya (BD)',
        'Seberang Perai Utara'   => 'Seberang Perai Utara (SPU)',
        'Seberang Perai Tengah'  => 'Seberang Perai Tengah (SPT)',
        'Seberang Perai Selatan' => 'Seberang Perai Selatan (SPS)',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function getTarikhPaAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhPaAttribute($value)
    {
        $this->attributes['tarikh_pa'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getPelanKunciAttribute()
    {
        $files = $this->getMedia('pelan_kunci');
        $files->each(function ($item) {
            $item->url       = $item->getUrl();
            $item->thumbnail = $item->getUrl('thumb');
            $item->preview   = $item->getUrl('preview');
        });

        return $files;
    }

    public function getPelanLokasiAttribute()
    {
        $files = $this->getMedia('pelan_lokasi');
        $files->each(function ($item) {
            $item->url       = $item->getUrl();
            $item->thumbnail = $item->getUrl('thumb');
            $item->preview   = $item->getUrl('preview');
        });

        return $files;
    }
}
