<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class MaklumatRakanUsahasama extends Model
{
    use SoftDeletes, Auditable, HasFactory;

    public $table = 'maklumat_rakan_usahasamas';

    protected $dates = [
        'tarikh_perjanjian_asal',
        'tarikh_perjanjian_tambahan',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'nama_syarikat',
        'tarikh_perjanjian_asal',
        'tarikh_perjanjian_tambahan',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function getTarikhPerjanjianAsalAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhPerjanjianAsalAttribute($value)
    {
        $this->attributes['tarikh_perjanjian_asal'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTarikhPerjanjianTambahanAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhPerjanjianTambahanAttribute($value)
    {
        $this->attributes['tarikh_perjanjian_tambahan'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }
}
