<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class RekodPulangan extends Model
{
    use SoftDeletes, Auditable, HasFactory;

    public $table = 'rekod_pulangans';

    public static $searchable = [
        'perkara',
        'tarikh',
        'jumlah_anggaran',
        'tarikh_bayaran',
    ];

    protected $dates = [
        'tarikh',
        'tarikh_bayaran',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const STATUS_BAYARAN_SELECT = [
        'Belum Diterima' => 'Belum Diterima',
        'Dalam Proses'   => 'Dalam Proses',
        'Diterima'       => 'Diterima',
    ];

    protected $fillable = [
        'bil_id',
        'perkara',
        'pihak_id',
        'tarikh',
        'jumlah_anggaran',
        'status_bayaran',
        'tarikh_bayaran',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function bil()
    {
        return $this->belongsTo(KategoriBilangan::class, 'bil_id');
    }

    public function pihak()
    {
        return $this->belongsTo(KategoriPihak::class, 'pihak_id');
    }

    public function getTarikhAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhAttribute($value)
    {
        $this->attributes['tarikh'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getTarikhBayaranAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhBayaranAttribute($value)
    {
        $this->attributes['tarikh_bayaran'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }
}
