<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class TempohPerlaksanaanProjek extends Model
{
    use SoftDeletes, Auditable, HasFactory;

    public $table = 'tempoh_perlaksanaan_projeks';

    protected $dates = [
        'tarikh_mula',
        'anggaran_tarikh_siap',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'perkara_pembangunan',
        'tarikh_mula',
        'anggaran_tarikh_siap',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function getTarikhMulaAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTarikhMulaAttribute($value)
    {
        $this->attributes['tarikh_mula'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getAnggaranTarikhSiapAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setAnggaranTarikhSiapAttribute($value)
    {
        $this->attributes['anggaran_tarikh_siap'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }
}
