@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.rekodPulangan.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.rekod-pulangans.update", [$rekodPulangan->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label for="bil_id">{{ trans('cruds.rekodPulangan.fields.bil') }}</label>
                <select class="form-control select2 {{ $errors->has('bil') ? 'is-invalid' : '' }}" name="bil_id" id="bil_id">
                    @foreach($bils as $id => $entry)
                        <option value="{{ $id }}" {{ (old('bil_id') ? old('bil_id') : $rekodPulangan->bil->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('bil'))
                    <span class="text-danger">{{ $errors->first('bil') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.bil_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="perkara">{{ trans('cruds.rekodPulangan.fields.perkara') }}</label>
                <textarea class="form-control {{ $errors->has('perkara') ? 'is-invalid' : '' }}" name="perkara" id="perkara" required>{{ old('perkara', $rekodPulangan->perkara) }}</textarea>
                @if($errors->has('perkara'))
                    <span class="text-danger">{{ $errors->first('perkara') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.perkara_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="pihak_id">{{ trans('cruds.rekodPulangan.fields.pihak') }}</label>
                <select class="form-control select2 {{ $errors->has('pihak') ? 'is-invalid' : '' }}" name="pihak_id" id="pihak_id">
                    @foreach($pihaks as $id => $entry)
                        <option value="{{ $id }}" {{ (old('pihak_id') ? old('pihak_id') : $rekodPulangan->pihak->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('pihak'))
                    <span class="text-danger">{{ $errors->first('pihak') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.pihak_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="tarikh">{{ trans('cruds.rekodPulangan.fields.tarikh') }}</label>
                <input class="form-control date {{ $errors->has('tarikh') ? 'is-invalid' : '' }}" type="text" name="tarikh" id="tarikh" value="{{ old('tarikh', $rekodPulangan->tarikh) }}">
                @if($errors->has('tarikh'))
                    <span class="text-danger">{{ $errors->first('tarikh') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.tarikh_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="jumlah_anggaran">{{ trans('cruds.rekodPulangan.fields.jumlah_anggaran') }}</label>
                <input class="form-control {{ $errors->has('jumlah_anggaran') ? 'is-invalid' : '' }}" type="number" name="jumlah_anggaran" id="jumlah_anggaran" value="{{ old('jumlah_anggaran', $rekodPulangan->jumlah_anggaran) }}" step="0.01">
                @if($errors->has('jumlah_anggaran'))
                    <span class="text-danger">{{ $errors->first('jumlah_anggaran') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.jumlah_anggaran_helper') }}</span>
            </div>
            <div class="form-group">
                <label>{{ trans('cruds.rekodPulangan.fields.status_bayaran') }}</label>
                <select class="form-control {{ $errors->has('status_bayaran') ? 'is-invalid' : '' }}" name="status_bayaran" id="status_bayaran">
                    <option value disabled {{ old('status_bayaran', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\RekodPulangan::STATUS_BAYARAN_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('status_bayaran', $rekodPulangan->status_bayaran) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('status_bayaran'))
                    <span class="text-danger">{{ $errors->first('status_bayaran') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.status_bayaran_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="tarikh_bayaran">{{ trans('cruds.rekodPulangan.fields.tarikh_bayaran') }}</label>
                <input class="form-control date {{ $errors->has('tarikh_bayaran') ? 'is-invalid' : '' }}" type="text" name="tarikh_bayaran" id="tarikh_bayaran" value="{{ old('tarikh_bayaran', $rekodPulangan->tarikh_bayaran) }}">
                @if($errors->has('tarikh_bayaran'))
                    <span class="text-danger">{{ $errors->first('tarikh_bayaran') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.rekodPulangan.fields.tarikh_bayaran_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection