<?php

Route::redirect('/', '/login');
Route::get('/home', function () {
    if (session('status')) {
        return redirect()->route('admin.home')->with('status', session('status'));
    }

    return redirect()->route('admin.home');
});

Route::get('userVerification/{token}', 'UserVerificationController@approve')->name('userVerification');
Auth::routes();

Route::group(['prefix' => 'admin', 'as' => 'admin.', 'namespace' => 'Admin', 'middleware' => ['auth']], function () {
    Route::get('/', 'HomeController@index')->name('home');
    // Permissions
    Route::delete('permissions/destroy', 'PermissionsController@massDestroy')->name('permissions.massDestroy');
    Route::resource('permissions', 'PermissionsController');

    // Roles
    Route::delete('roles/destroy', 'RolesController@massDestroy')->name('roles.massDestroy');
    Route::resource('roles', 'RolesController');

    // Users
    Route::delete('users/destroy', 'UsersController@massDestroy')->name('users.massDestroy');
    Route::resource('users', 'UsersController');

    // User Alerts
    Route::delete('user-alerts/destroy', 'UserAlertsController@massDestroy')->name('user-alerts.massDestroy');
    Route::get('user-alerts/read', 'UserAlertsController@read');
    Route::resource('user-alerts', 'UserAlertsController', ['except' => ['edit', 'update']]);

    // Audit Logs
    Route::resource('audit-logs', 'AuditLogsController', ['except' => ['create', 'store', 'edit', 'update', 'destroy']]);

    // Task Status
    Route::delete('task-statuses/destroy', 'TaskStatusController@massDestroy')->name('task-statuses.massDestroy');
    Route::post('task-statuses/parse-csv-import', 'TaskStatusController@parseCsvImport')->name('task-statuses.parseCsvImport');
    Route::post('task-statuses/process-csv-import', 'TaskStatusController@processCsvImport')->name('task-statuses.processCsvImport');
    Route::resource('task-statuses', 'TaskStatusController');

    // Task Tag
    Route::delete('task-tags/destroy', 'TaskTagController@massDestroy')->name('task-tags.massDestroy');
    Route::resource('task-tags', 'TaskTagController');

    // Task
    Route::delete('tasks/destroy', 'TaskController@massDestroy')->name('tasks.massDestroy');
    Route::post('tasks/media', 'TaskController@storeMedia')->name('tasks.storeMedia');
    Route::post('tasks/ckmedia', 'TaskController@storeCKEditorImages')->name('tasks.storeCKEditorImages');
    Route::post('tasks/parse-csv-import', 'TaskController@parseCsvImport')->name('tasks.parseCsvImport');
    Route::post('tasks/process-csv-import', 'TaskController@processCsvImport')->name('tasks.processCsvImport');
    Route::resource('tasks', 'TaskController');

    // Tasks Calendar
    Route::resource('tasks-calendars', 'TasksCalendarController', ['except' => ['create', 'store', 'edit', 'update', 'show', 'destroy']]);

    // Maklumat Project
    Route::delete('maklumat-projects/destroy', 'MaklumatProjectController@massDestroy')->name('maklumat-projects.massDestroy');
    Route::post('maklumat-projects/media', 'MaklumatProjectController@storeMedia')->name('maklumat-projects.storeMedia');
    Route::post('maklumat-projects/ckmedia', 'MaklumatProjectController@storeCKEditorImages')->name('maklumat-projects.storeCKEditorImages');
    Route::post('maklumat-projects/parse-csv-import', 'MaklumatProjectController@parseCsvImport')->name('maklumat-projects.parseCsvImport');
    Route::post('maklumat-projects/process-csv-import', 'MaklumatProjectController@processCsvImport')->name('maklumat-projects.processCsvImport');
    Route::resource('maklumat-projects', 'MaklumatProjectController');

    // Maklumat Rakan Usahasama
    Route::delete('maklumat-rakan-usahasamas/destroy', 'MaklumatRakanUsahasamaController@massDestroy')->name('maklumat-rakan-usahasamas.massDestroy');
    Route::post('maklumat-rakan-usahasamas/parse-csv-import', 'MaklumatRakanUsahasamaController@parseCsvImport')->name('maklumat-rakan-usahasamas.parseCsvImport');
    Route::post('maklumat-rakan-usahasamas/process-csv-import', 'MaklumatRakanUsahasamaController@processCsvImport')->name('maklumat-rakan-usahasamas.processCsvImport');
    Route::resource('maklumat-rakan-usahasamas', 'MaklumatRakanUsahasamaController');

    // Maklumat Perunding
    Route::delete('maklumat-perundings/destroy', 'MaklumatPerundingController@massDestroy')->name('maklumat-perundings.massDestroy');
    Route::post('maklumat-perundings/parse-csv-import', 'MaklumatPerundingController@parseCsvImport')->name('maklumat-perundings.parseCsvImport');
    Route::post('maklumat-perundings/process-csv-import', 'MaklumatPerundingController@processCsvImport')->name('maklumat-perundings.processCsvImport');
    Route::resource('maklumat-perundings', 'MaklumatPerundingController');

    // Tempoh Perlaksanaan Projek
    Route::delete('tempoh-perlaksanaan-projeks/destroy', 'TempohPerlaksanaanProjekController@massDestroy')->name('tempoh-perlaksanaan-projeks.massDestroy');
    Route::post('tempoh-perlaksanaan-projeks/parse-csv-import', 'TempohPerlaksanaanProjekController@parseCsvImport')->name('tempoh-perlaksanaan-projeks.parseCsvImport');
    Route::post('tempoh-perlaksanaan-projeks/process-csv-import', 'TempohPerlaksanaanProjekController@processCsvImport')->name('tempoh-perlaksanaan-projeks.processCsvImport');
    Route::resource('tempoh-perlaksanaan-projeks', 'TempohPerlaksanaanProjekController');

    // Komponen Pembangunan
    Route::delete('komponen-pembangunans/destroy', 'KomponenPembangunanController@massDestroy')->name('komponen-pembangunans.massDestroy');
    Route::post('komponen-pembangunans/media', 'KomponenPembangunanController@storeMedia')->name('komponen-pembangunans.storeMedia');
    Route::post('komponen-pembangunans/ckmedia', 'KomponenPembangunanController@storeCKEditorImages')->name('komponen-pembangunans.storeCKEditorImages');
    Route::post('komponen-pembangunans/parse-csv-import', 'KomponenPembangunanController@parseCsvImport')->name('komponen-pembangunans.parseCsvImport');
    Route::post('komponen-pembangunans/process-csv-import', 'KomponenPembangunanController@processCsvImport')->name('komponen-pembangunans.processCsvImport');
    Route::resource('komponen-pembangunans', 'KomponenPembangunanController');

    // Isu
    Route::delete('isus/destroy', 'IsuController@massDestroy')->name('isus.massDestroy');
    Route::post('isus/media', 'IsuController@storeMedia')->name('isus.storeMedia');
    Route::post('isus/ckmedia', 'IsuController@storeCKEditorImages')->name('isus.storeCKEditorImages');
    Route::post('isus/parse-csv-import', 'IsuController@parseCsvImport')->name('isus.parseCsvImport');
    Route::post('isus/process-csv-import', 'IsuController@processCsvImport')->name('isus.processCsvImport');
    Route::resource('isus', 'IsuController');

    // Expense Category
    Route::delete('expense-categories/destroy', 'ExpenseCategoryController@massDestroy')->name('expense-categories.massDestroy');
    Route::resource('expense-categories', 'ExpenseCategoryController');

    // Income Category
    Route::delete('income-categories/destroy', 'IncomeCategoryController@massDestroy')->name('income-categories.massDestroy');
    Route::resource('income-categories', 'IncomeCategoryController');

    // Expense
    Route::delete('expenses/destroy', 'ExpenseController@massDestroy')->name('expenses.massDestroy');
    Route::resource('expenses', 'ExpenseController');

    // Income
    Route::delete('incomes/destroy', 'IncomeController@massDestroy')->name('incomes.massDestroy');
    Route::resource('incomes', 'IncomeController');

    // Expense Report
    Route::delete('expense-reports/destroy', 'ExpenseReportController@massDestroy')->name('expense-reports.massDestroy');
    Route::resource('expense-reports', 'ExpenseReportController');

    // Kategori Bilangan
    Route::delete('kategori-bilangans/destroy', 'KategoriBilanganController@massDestroy')->name('kategori-bilangans.massDestroy');
    Route::post('kategori-bilangans/parse-csv-import', 'KategoriBilanganController@parseCsvImport')->name('kategori-bilangans.parseCsvImport');
    Route::post('kategori-bilangans/process-csv-import', 'KategoriBilanganController@processCsvImport')->name('kategori-bilangans.processCsvImport');
    Route::resource('kategori-bilangans', 'KategoriBilanganController');

    // Kategori Pihak
    Route::delete('kategori-pihaks/destroy', 'KategoriPihakController@massDestroy')->name('kategori-pihaks.massDestroy');
    Route::post('kategori-pihaks/parse-csv-import', 'KategoriPihakController@parseCsvImport')->name('kategori-pihaks.parseCsvImport');
    Route::post('kategori-pihaks/process-csv-import', 'KategoriPihakController@processCsvImport')->name('kategori-pihaks.processCsvImport');
    Route::resource('kategori-pihaks', 'KategoriPihakController');

    // Rekod Pulangan
    Route::delete('rekod-pulangans/destroy', 'RekodPulanganController@massDestroy')->name('rekod-pulangans.massDestroy');
    Route::post('rekod-pulangans/parse-csv-import', 'RekodPulanganController@parseCsvImport')->name('rekod-pulangans.parseCsvImport');
    Route::post('rekod-pulangans/process-csv-import', 'RekodPulanganController@processCsvImport')->name('rekod-pulangans.processCsvImport');
    Route::resource('rekod-pulangans', 'RekodPulanganController');

    // Reportbaru
    Route::delete('reportbarus/destroy', 'ReportbaruController@massDestroy')->name('reportbarus.massDestroy');
    Route::resource('reportbarus', 'ReportbaruController');

    Route::get('system-calendar', 'SystemCalendarController@index')->name('systemCalendar');
    Route::get('global-search', 'GlobalSearchController@search')->name('globalSearch');
    Route::get('messenger', 'MessengerController@index')->name('messenger.index');
    Route::get('messenger/create', 'MessengerController@createTopic')->name('messenger.createTopic');
    Route::post('messenger', 'MessengerController@storeTopic')->name('messenger.storeTopic');
    Route::get('messenger/inbox', 'MessengerController@showInbox')->name('messenger.showInbox');
    Route::get('messenger/outbox', 'MessengerController@showOutbox')->name('messenger.showOutbox');
    Route::get('messenger/{topic}', 'MessengerController@showMessages')->name('messenger.showMessages');
    Route::delete('messenger/{topic}', 'MessengerController@destroyTopic')->name('messenger.destroyTopic');
    Route::post('messenger/{topic}/reply', 'MessengerController@replyToTopic')->name('messenger.reply');
    Route::get('messenger/{topic}/reply', 'MessengerController@showReply')->name('messenger.showReply');
});
Route::group(['prefix' => 'profile', 'as' => 'profile.', 'namespace' => 'Auth', 'middleware' => ['auth']], function () {
    // Change password
    if (file_exists(app_path('Http/Controllers/Auth/ChangePasswordController.php'))) {
        Route::get('password', 'ChangePasswordController@edit')->name('password.edit');
        Route::post('password', 'ChangePasswordController@update')->name('password.update');
        Route::post('profile', 'ChangePasswordController@updateProfile')->name('password.updateProfile');
        Route::post('profile/destroy', 'ChangePasswordController@destroy')->name('password.destroyProfile');
    }
});
